@@ -28,7 +28,7 @@ class Client:
         self.__tree_id = credentials["tree_id"]
         self.__branch_id = credentials["branch_id"]
 
-        self.__logged_in = False
+        self.__status = False
         self.__access_token = None
         self.__leaf_id = None
 
@@ -38,8 +38,8 @@ class Client:
 
         self.queue = Queue()
 
-        consumer = Consumer(credentials, self.queue)
-        self.consumer = consumer.spawn_consumer_thread()
+        self.rabbit_credentials = credentials
+        self.consumer = None
         return
 
     def disable_ssl_verification(self, enabled=False):
@@ -99,8 +99,12 @@ class Client:
             try:
                 self.__leaf_id = login_data["id"]
                 self.__access_token = login_data["access_token"]
-                self.__logged_in = login_data["logged_in"]
-                return self.__logged_in
+                self.__status = login_data["status"]
+                self.rabbit_credentials["queue_password"] = self.__access_token
+                self.rabbit_credentials["leaf_id"] = self.__leaf_id
+                consumer = Consumer(self.rabbit_credentials, self.queue)
+                self.consumer = consumer.spawn_consumer_thread()
+                return self.__status == "logged_in"
             except Exception as e:
                 msg = "Failed to parse response from login"
                 raise Exception(msg)
@@ -110,7 +114,7 @@ class Client:
             raise Exception(msg)
 
     def logout(self):
-        if not self.__logged_in or not self.__access_token:
+        if not self.__status == "logged_in" or not self.__access_token:
             msg = "Logout failed for {}: not logged in or no access_token present".format(self.__leaf_name)
             raise Exception(msg)
         try:
@@ -119,10 +123,10 @@ class Client:
             resp = requests.put(url, auth=(self.__leaf_name, self.__leaf_password), verify=self.__verify)
 
             if resp.status_code != HTTPStatus.OK:
-                raise Exception(f"Error with login: status code {resp.status_code}")
+                raise Exception(f"{resp.json()['message']}")
 
             self.__access_token = None
-            self.__logged_in = False
+            self.__status = "logged_out"
             return True
 
         except Exception as e:
@@ -130,7 +134,7 @@ class Client:
             raise Exception(msg)
 
     def file_upload(self, file_path):
-        if self.__logged_in:
+        if self.__status == "logged_in":
             try:
                 with open(file_path, mode="rb") as f:
                     self.validate_weight_shape(f)
@@ -159,7 +163,7 @@ class Client:
             raise Exception(msg)
 
     def file_download(self, file_id):
-        if self.__logged_in:
+        if self.__status == "logged_in":
             try:
                 if not os.path.exists(AGGREGATED_OUTPUT_DIR):
                     os.makedirs(AGGREGATED_OUTPUT_DIR)
@@ -197,4 +201,4 @@ class Client:
 
     @property
     def is_logged_in(self):
-        return self.__logged_in
+        return self.__status == "logged_in"
